@@ -14,6 +14,104 @@ from scipy.misc import factorial
 from .errors import KineticlibError
 
 
+def omega(T: float, l: int, r: int, idata: np.ndarray, model: str='IPL', dimensional: bool=True,
+          nokt: bool=False) -> float:
+    """Returns the :math:`\\Omega^{(l,r)}`-integral for a specified potential
+
+    Parameters
+    ----------
+    T : float
+        the temperature of the mixture
+    l : int
+        the l degree of the integral
+    r : int
+        the r degree of the integral
+    idata : 1-D array-like
+        the array of interaction data
+    model : str
+        the interaction model to be used, possible values:
+            * 'IPL' (Inverse Power Law potential)
+            * 'LJ' (Lennard-Jones potential)
+            * 'RS' (Rigid Sphere model)
+            * 'VSS' (Variable Soft Sphere model)
+            * 'Switch' (returns the result for the Lennard-Jones model when :math:`T / \\varepsilon_{cd} < 10`
+              and for the IPL potential otherwise)
+            * 'ESA' (model given in the paper *Transport Properties of High-Temperature Mars-Atmosphere Components*)
+
+        defaults to 'IPL'
+    dimensional : bool
+        if True, then the dimensional :math:`\\Omega^{(l,r)}`-integral is returned, otherwise,
+        the dimensionless :math:`\\Omega^{(l,r)}`-integral is returned (dimensional integral divided by the same
+        integral for the Rigid Sphere model), defaults to True
+    nokt : bool, optional
+        if True and `dimensional` is True, the result will be multiplied by :math:`\\sqrt{(1 / kT)}`, defaults to False
+
+    Returns
+    -------
+    float
+        The :math:`\\Omega^{(l,r)}`-integral calculated using the selected potential
+
+    Raises
+    ------
+    KineticlibError
+        For the 'VSS', 'LJ', 'IPL' and 'Switch' models: if `l!=r` or `l` not in `{1,2}`,
+        for the 'ESA' model: if `(l,r)` not in `{(1,1), (1,2), (1,3), (1,4), (1,5), (2,2), (2,3), (2,4), (3,3), (4,4)}`
+    """
+    m = idata[0]
+    sigma = idata[1]
+    eps = idata[2]
+    phizero = idata[3]
+    beta = idata[4]
+    vssc_11 = idata[5]
+    vsso_11 = idata[6]
+    vssc_22 = idata[7]
+    vsso_22 = idata[8]
+
+    if model == 'LJ' and l == r:
+        if dimensional is True:
+            return omega_dimless_LJ(T, l, eps) * rigid_sphere_omega(T, l, l, m, sigma, nokt)
+        else:
+            return omega_dimless_LJ(T, l, eps)
+    elif model == 'ESA':
+        if dimensional is True:
+            return omega_esa(T, l, r, idata[13], idata[14]) * rigid_sphere_omega(T, l, r, m, sigma, nokt)
+        else:
+            return omega_esa(T, l, r, idata[13], idata[14])
+    elif model == 'RS':
+        if dimensional is True:
+            return rigid_sphere_omega(T, l, r, m, sigma, nokt)
+        else:
+            return 1.0
+    elif model == 'Switch' and l == r:  # eps/kT > 10
+        if T / eps > 10:
+            om_dimless = omega_dimless_IPL(T, l, sigma, eps, phizero, beta)
+        else:
+            om_dimless = omega_dimless_LJ(T, l, eps)
+        if dimensional is True:
+            return om_dimless * rigid_sphere_omega(T, l, r, m, sigma, nokt)
+        else:
+            return om_dimless
+    elif model == 'IPL' and l == r:
+        if dimensional is True:
+            return omega_dimless_IPL(T, l, sigma, eps, phizero, beta) * rigid_sphere_omega(T, l, r, m, sigma, nokt)
+        else:
+            return omega_dimless_IPL(T, l, sigma, eps, phizero, beta)
+    elif model == 'VSS' and l == r:
+        if l == 1:
+            if dimensional is True:
+                return omega_vss(T, l, m, vssc_11, vsso_11, nokt)
+            else:
+                return omega_vss(T, l, m, vssc_11, vsso_11, nokt) / rigid_sphere_omega(T, l, r, m, sigma, False)
+        elif l == 2:
+            if dimensional is True:
+                return omega_vss(T, l, m, vssc_22, vsso_22, nokt)
+            else:
+                return omega_vss(T, l, m, vssc_22, vsso_22, nokt) / rigid_sphere_omega(T, l, r, m, sigma, False)
+    else:
+        raise KineticlibError('Cannot calculate the Omega^{(' + str(l) + ',' + str(r)
+                              + ')} integral using the ' + model + ' potential')
+
+
 def rigid_sphere_omega(T: float, l: int, r: int, m: float, sigma: float, nokt: bool=False) -> float:
     """Returns the :math:`\\Omega^{(l,r)}`-integral for a rigid sphere potential for any `l > 0`  and `r > 0`
 
@@ -30,7 +128,7 @@ def rigid_sphere_omega(T: float, l: int, r: int, m: float, sigma: float, nokt: b
     sigma : float
         the collision diameter :math:`\\sigma_{cd}`
     nokt : bool, optional
-        if True and full_integral is True, the result will be multiplied by :math:`\\sqrt{(1 / kT)}`, defaults to True
+        if True and full_integral is True, the result will be multiplied by :math:`\\sqrt{(1 / kT)}`, defaults to False
 
     Returns
     -------
@@ -152,7 +250,7 @@ def omega_vss(T: float, l: int, m: float, vssc: float, vsso: float, nokt: bool=F
     vsso : float
         the VSS potential :math:`\\omega` parameter
     nokt : bool, optional
-        if True and full_integral is True, the result will be multiplied by :math:`\\sqrt{(1 / kT)}`, defaults to True
+        if True and full_integral is True, the result will be multiplied by :math:`\\sqrt{(1 / kT)}`, defaults to False
 
     Returns
     -------
@@ -409,102 +507,4 @@ def omega_esa(T: float, l: int, r: int, beta: float, eps: float) -> float:
                                       / (np.exp((x - a[2]) / a[3]) + np.exp((a[2] - x) / a[3]))\
                     + a[4] * np.exp((x - a[5]) / a[6]) \
                            / (np.exp((x - a[5]) / a[6]) + np.exp((a[5] - x) / a[6]))
-    return np.exp(dimless_omega)
-
-
-def omega(T: float, l: int, r: int, idata: np.ndarray, model: str='IPL', dimensional: bool=True,
-          nokt: bool=False) -> float:
-    """Returns the :math:`\\Omega^{(l,r)}`-integral for a specified potential
-
-    Parameters
-    ----------
-    T : float
-        the temperature of the mixture
-    l : int
-        the l degree of the integral
-    r : int
-        the r degree of the integral
-    idata : 1-D array-like
-        the array of interaction data
-    model : str
-        the interaction model to be used, possible values:
-            * 'IPL' (Inverse Power Law potential)
-            * 'LJ' (Lennard-Jones potential)
-            * 'RS' (Rigid Sphere model)
-            * 'VSS' (Variable Soft Sphere model)
-            * 'Switch' (returns the result for the Lennard-Jones model when :math:`T / \\varepsilon_{cd} < 10`
-              and for the IPL potential otherwise)
-            * 'ESA' (model given in the paper *Transport Properties of High-Temperature Mars-Atmosphere Components*)
-
-        defaults to 'IPL'
-    dimensional : bool
-        if True, then the dimensional :math:`\\Omega^{(l,r)}`-integral is returned, otherwise,
-        the dimensionless :math:`\\Omega^{(l,r)}`-integral is returned (dimensional integral divided by the same
-        integral for the Rigid Sphere model)
-    nokt : bool, optional
-        if True and `dimensional` is True, the result will be multiplied by :math:`\\sqrt{(1 / kT)}`, defaults to True
-
-    Returns
-    -------
-    float
-        The :math:`\\Omega^{(l,r)}`-integral calculated using the selected potential
-
-    Raises
-    ------
-    KineticlibError
-        For the 'VSS', 'LJ', 'IPL' and 'Switch' models: if `l!=r` or `l` not in `{1,2}`,
-        for the 'ESA' model: if `(l,r)` not in `{(1,1), (1,2), (1,3), (1,4), (1,5), (2,2), (2,3), (2,4), (3,3), (4,4)}`
-    """
-    m = idata[0]
-    sigma = idata[1]
-    eps = idata[2]
-    phizero = idata[3]
-    beta = idata[4]
-    vssc_11 = idata[5]
-    vsso_11 = idata[6]
-    vssc_22 = idata[7]
-    vsso_22 = idata[8]
-
-    if model == 'LJ' and l == r:
-        if dimensional is True:
-            return omega_dimless_LJ(T, l, eps) * rigid_sphere_omega(T, l, l, m, sigma, nokt)
-        else:
-            return omega_dimless_LJ(T, l, eps)
-    elif model == 'ESA':
-        if dimensional is True:
-            return omega_esa(T, l, r, idata[13], idata[14]) * rigid_sphere_omega(T, l, r, m, sigma, nokt)
-        else:
-            return omega_esa(T, l, r, idata[13], idata[14])
-    elif model == 'RS':
-        if dimensional is True:
-            return rigid_sphere_omega(T, l, r, m, sigma, nokt)
-        else:
-            return 1.0
-    elif model == 'Switch' and l == r:  # eps/kT > 10
-        if T / eps > 10:
-            om_dimless = omega_dimless_IPL(T, l, sigma, eps, phizero, beta)
-        else:
-            om_dimless = omega_dimless_LJ(T, l, eps)
-        if dimensional is True:
-            return om_dimless * rigid_sphere_omega(T, l, r, m, sigma, nokt)
-        else:
-            return om_dimless
-    elif model == 'IPL' and l == r:
-        if dimensional is True:
-            return omega_dimless_IPL(T, l, sigma, eps, phizero, beta) * rigid_sphere_omega(T, l, r, m, sigma, nokt)
-        else:
-            return omega_dimless_IPL(T, l, sigma, eps, phizero, beta)
-    elif model == 'VSS' and l == r:
-        if l == 1:
-            if dimensional is True:
-                return omega_vss(T, l, m, vssc_11, vsso_11, nokt)
-            else:
-                return omega_vss(T, l, m, vssc_11, vsso_11, True) / rigid_sphere_omega(T, l, r, m, sigma, True)
-        elif l == 2:
-            if dimensional is True:
-                return omega_vss(T, l, m, vssc_22, vsso_22, nokt)
-            else:
-                return omega_vss(T, l, m, vssc_22, vsso_22, True) / rigid_sphere_omega(T, l, r, m, sigma, True)
-    else:
-        raise KineticlibError('Cannot calculate the Omega^{(' + str(l) + ',' + str(r)
-                              + ')} integral using the ' + model + ' potential')
\ No newline at end of file
+    return np.exp(dimless_omega)
\ No newline at end of file
