@@ -628,6 +628,7 @@ class Molecule(MoleculeSTS):
         self.max_vibr = self.num_vibr
         self._current_T1 = 1.0
         self._current_Z_vibr = 0.0
+        self._current_Z_int = 0.0
         self._current_n = 0.0
         self._current_ni = np.zeros(self.num_vibr + 1)
         self._current_v_exp = np.zeros(self.num_vibr + 1)
@@ -672,6 +673,7 @@ class Molecule(MoleculeSTS):
         MoleculeSTS.renorm_sts(self, T)
 
         self._current_Z_vibr = self.Z_vibr(T, T1)
+        self._current_Z_int = self.Z_int(T, T1)
         self._current_vae_dimensionless = self.avg_vibr_energy(T, T1, False)
         self._current_vae = self.avg_vibr_energy(T, T1, True)
         self._current_vaesq = self.avg_vibr_energy_sq(T, T1, True)
@@ -755,6 +757,26 @@ class Molecule(MoleculeSTS):
         else:
             return self._current_Z_vibr
 
+    def Z_int(self, T: float, T1: float) -> float:
+        """Returns the internal partition function :math:`Z_{int}(T, T_{1}) = Z_{rot}(T) Z_{vibr}(T, T_{1})`
+
+        Parameters
+        ----------
+        T : float
+            the temperature of the mixture
+        T1 : float
+            the temperature of the first vibrational level for the molecular species
+
+        Returns
+        -------
+        float
+            The vibrational partition function
+        """
+        if (self._current_T != T) or (self._current_T1 != T1):
+            return self.Z_rot(T) * self.Z_vibr(T, T1)
+        else:
+            return self._current_Z_int
+
     def avg_vibr_energy(self, T: float, T1: float, dimensional: bool=True) -> float:
         """Returns the vibrational energy averaged over the vibrational spectrum (either dimensional
         :math:`\\left<\\varepsilon^{vibr} \\right>_{vibr}` or dimensionless
